Tome

Struct Tome 

pub struct Tome { /* private fields */ }
This is where all of the transmutation circles are inscribed.

Implementations

Source

impl Tome

pub fn new() -> Self

Create an empty tome.

pub fn inscribe<T: Transmutation + 'static>(&mut self, circle: T)

Inscribe a note about a natural transmutation into the tome.

pub fn ether<T: Clone + 'static>(&mut self, item: T)

Create a note about how to create something out of the ether.

pub fn summon<T: 'static>(&self) -> Option<T>

Give me what I want.